# Supported Providers and Models

This page lists the supported providers and their available models.

## OpenAI

- GPT-5 (default)
- GPT-5 Mini
- GPT-5 Nano
- GPT-4
- GPT-4 Turbo
- GPT-3.5 Turbo

For setup instructions, see the [OpenAI Setup Guide](openai-setup.md).

## Google

- Gemini Pro
- Gemini 1.5 Pro

## Anthropic

- Claude 2
- Claude 3 Opus
- Claude 3 Sonnet
- Claude 3 Haiku

## MoonshotAI

- kimi-k2-turbo-preview
- kimi-k2-turbo-preview
- kimi-k1-8k
- kimi-k1-32k
- kimi-k1-128k

- Llama-3-8b-8192
- Llama-3-70b-8192

## Alibaba

- qwen-turbo
- qwen-plus
- qwen-max
- qwen3-coder-plus (default)
- qwen3-coder-480b-a35b-instruct
- qwen3-235b-a22b-thinking-2507
- qwen3-235b-a22b-instruct-2507
- qwen3-30b-a3b-thinking-2507
- qwen3-30b-a3b-instruct-2507

## Z.AI

- glm-4.5
- glm-4.5-air

## Cerebras

**Production Models:**

- llama-4-scout-17b-16e-instruct
- llama-3.3-70b
- llama3.1-8b
- qwen-3-32b

**Preview Models:**

- llama-4-maverick-17b-128e-instruct
- qwen-3-235b-a22b-instruct-2507
- qwen-3-235b-a22b-thinking-2507
- qwen-3-coder-480b
- gpt-oss-120b

**Notes:**

- qwen-3-coder-480b: 32k context, reasoning-focused model with function calling support

<!-- Removed links to model_info.py files for all providers to avoid broken references. -->
